package
Version:
v0.0.0-...-64d0ec3
Opens a new window with list of versions in this module.
Published: Feb 5, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Request struct {
Project string `json:"project"`
Group string `json:"group"`
Description string `json:"description"`
Method string `json:"method"`
URL string `json:"url"`
Body string `json:"body"`
}
Request type
Valid checks is request spec valid
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.